run_update

Function run_update 

pub fn run_update<B, T>(
    view: &AccountView<'_>,
    args: &B::Args,
    _proof: &BehaviorChecked<B, B::CheckOutput>,
) -> ProgramResult
where T: LayoutContract + Pod, B: HopperBehavior<T>,
Run behavior B’s update phase through the typed mutable path.

Requires the proof token from run_check, so this helper cannot run an update without a successful check token of the same behavior type.