macro_rules! require {
( $cond:expr, $err:expr ) => { ... };
( $cond:expr ) => { ... };
}Expand description
Early-return with an error if the condition is false.
macro_rules! require {
( $cond:expr, $err:expr ) => { ... };
( $cond:expr ) => { ... };
}Early-return with an error if the condition is false.