Module memory

Module memory 

Hopper-owned memory helpers backed by Solana memory syscalls.

These helpers keep raw SVM memory operations behind Hopper Runtime, while the safe wrappers operate on Rust slices for normal program code.

Functions

bytes_eq
Equality helper for byte slices.
compare⚠
Lexicographically compare two raw memory ranges.
compare_bytes
Compare two slices through Hopper’s memory boundary.
copy⚠
Copy bytes from src to dst, allowing overlap.
copy_bytes
Copy src into the beginning of dst.
copy_nonoverlapping⚠
Copy bytes from src to dst. The regions must not overlap.
fill⚠
Fill a raw memory range with one byte.
fill_bytes
Fill a byte slice with byte.
move_within
Move a byte range inside one buffer, allowing overlap.
zero_bytes
Zero-fill a byte slice.