SegmentBorrowGuard

Struct SegmentBorrowGuard 

pub struct SegmentBorrowGuard<'a> { /* private fields */ }
RAII guard that releases a segment borrow when dropped.

Created by SegmentBorrowRegistry::register_guard() and its convenience wrappers. The borrow is automatically released from the registry on drop, preventing borrow leaks.

Implementations

Source

impl<'a> SegmentBorrowGuard<'a>

pub fn kind(&self) -> AccessKind

Access kind of the guarded borrow.

pub fn offset(&self) -> u32

Byte offset of the guarded segment.

pub fn size(&self) -> u32

Byte size of the guarded segment.