pub fn require_non_transferable(mint: &AccountView<'_>) -> ProgramResultExpand description
Require a mint to carry the NonTransferable extension.
Use when a program is designed to only ever mint soulbound tokens.
pub fn require_non_transferable(mint: &AccountView<'_>) -> ProgramResultRequire a mint to carry the NonTransferable extension.
Use when a program is designed to only ever mint soulbound tokens.