Hopper-owned memory helpers backed by Solana memory syscalls.
These helpers keep raw SVM memory operations behind Hopper Runtime, while the safe wrappers operate on Rust slices for normal program code.
Functions
- bytes_
eq - Equality helper for byte slices.
- compare⚠
- Lexicographically compare two raw memory ranges.
- compare_
bytes - Compare two slices through Hopper’s memory boundary.
- copy⚠
- Copy bytes from
srctodst, allowing overlap. - copy_
bytes - Copy
srcinto the beginning ofdst. - copy_
nonoverlapping ⚠ - Copy bytes from
srctodst. The regions must not overlap. - fill⚠
- Fill a raw memory range with one byte.
- fill_
bytes - Fill a byte slice with
byte. - move_
within - Move a byte range inside one buffer, allowing overlap.
- zero_
bytes - Zero-fill a byte slice.