pub fn require_non_transferable(mint: &AccountView) -> ProgramResultExpand description
Require a mint to carry the NonTransferable extension.
Use when a program is designed to only ever mint soulbound tokens.
pub fn require_non_transferable(mint: &AccountView) -> ProgramResultRequire a mint to carry the NonTransferable extension.
Use when a program is designed to only ever mint soulbound tokens.