pub struct InitializeMint2<'a, 'b> {
pub mint: &'a AccountView<'a>,
pub program: MintProgram,
pub config: MintConfig<'b>,
}Expand description
Low-level InitializeMint2 CPI builder for either token program.
The token processor checks allocation, rent, extension compatibility and
initialization state. Use MintPlan to also bind allocation and extension
initialization together. The mint must have been allocated and assigned to
the selected token program already.
Fields
mint: &'a AccountView<'a>program: MintProgramconfig: MintConfig<'b>Implementations
Sourceimpl InitializeMint2<'_, '_>
impl InitializeMint2<'_, '_>
pub fn invoke(&self) -> ProgramResult